@@ -191,7 +191,9 @@ def do_get_templ(args):
         print(f"{args.saveto} is file")
         return 1
 
-    trtpy.init(cuda_version=args.cuda, tensorrt_version=args.trt, load_lean_library=False)
+    if not args.raw:
+        trtpy.init(cuda_version=args.cuda, tensorrt_version=args.trt, load_lean_library=False)
+        
     url = f"{trtpy.pypi_base_url}/code_template/{args.template}.zip"
     cache_zip = os.path.join(downloader.CACHE_ROOT, "code_template", f"{args.template}.zip")
     if not args.download and os.path.exists(cache_zip):
@@ -420,6 +422,64 @@ def do_templ_search(args):
         print(f"-{i+1}. {name} [{language}] : {descript}")
     return 0
 
+def do_series_list(args):
+
+    url = f"{trtpy.pypi_base_url}/code_template/list.series.txt"
+    resp = requests.get(url)
+    if resp.status_code != 200:
+        print("Can not fetch series list")
+        return 1
+
+    list_info = resp.content.decode("utf-8").split("\n")
+    list_info = [item.strip().split(";") for item in list_info if item.strip() != ""]
+
+    print(f"Found {len(list_info)} items:")
+    for i, line in enumerate(list_info):
+        name = line[0] if len(line) > 0 else ""
+        language = line[1] if len(line) > 1 else ""
+        descript = line[2] if len(line) > 2 else ""
+        print(f"-{i+1}. {name} [{language}] : {descript}")
+    return 0
+
+
+def do_series_search(args):
+    url = f"{trtpy.pypi_base_url}/code_template/list.series.txt"
+    resp = requests.get(url)
+    if resp.status_code != 200:
+        print("Can not fetch series list")
+        return 1
+
+    list_info = resp.content.decode("utf-8").split("\n")
+    list_info = [item.strip().split(";") for item in list_info if item.strip() != ""]
+    pattern = args.pattern
+    def pattern_match(pattern, value : str):
+        array = pattern.lower().split("%")
+        value = value.lower()
+        if len(array) == 0: return False
+        i = 0
+        p = 0
+        while i < len(array):
+            item = array[i]
+            p = value.find(item, p)
+            if p == -1: return False
+            p += len(item)
+            i += 1
+        return True
+
+    list_info = [item for item in list_info if pattern_match(pattern, item[0])]
+
+    if len(list_info) == 0:
+        print(f"Not found any items match for '{pattern}'")
+        return 1
+
+    print(f"Found {len(list_info)} items for '{pattern}':")
+    for i, line in enumerate(list_info):
+        name = line[0] if len(line) > 0 else ""
+        language = line[1] if len(line) > 1 else ""
+        descript = line[2] if len(line) > 2 else ""
+        print(f"-{i+1}. {name} [{language}] : {descript}")
+    return 0
+
 def do_mnist_test(args):
     trtpy.init(args.cuda, args.trt)
     trtpy.compile_onnx_to_file(1, trtpy.onnx_hub("mnist"), "mnist.trtmodel")
@@ -570,6 +630,10 @@ if __name__ == "__main__":
     p.add_argument("--raw", action="store_true", help="do not replace variables")
     p.add_argument("--download", action="store_true", help="ignore cache and download template")
 
+    subp.add_parser("list-series", help="display all series template")
+    p = subp.add_parser("search-series", help="search all series template")
+    p.add_argument("pattern", type=str, help="search name, yolo* etc.")
+
     p = new_parser_with_version("get-series", help="fetch series template")
     p.add_argument("name", type=str, help="series name")
     p.add_argument("saveto", type=str, help="save to directory, default[template name]", nargs="?")
@@ -624,6 +688,8 @@ if __name__ == "__main__":
         "env-source":    do_env_source,
         "inv-vars":      do_invert_variable,
         "get-series":    do_get_series,
+        "list-series":   do_series_list,
+        "search-series": do_series_search,
         "change-proj":   do_change_proj
     }
 
